@@ -42,7 +42,7 @@ static XMP_Node * sDummySchema = 0;	// ! Used for some ugliness with aliases.
 // Add the top level properties to the IterNode for a schema.
 
 static void
-AddSchemaProps ( IterInfo & info, IterNode & iterSchema, const XMP_Node * xmpSchema )
+AddSchemaProps ( IterInfo & /*info*/, IterNode & iterSchema, const XMP_Node * xmpSchema )
 {
 	#if TraceIterators
 		printf ( "    Adding properties of %s\n", xmpSchema->name.c_str() );
@@ -479,21 +479,6 @@ XMPIterator::XMPIterator ( const XMPMeta & xmpObj,
 	
 }	// XMPIterator for XMPMeta objects
 
-// -------------------------------------------------------------------------------------------------
-// XMPIterator
-// -----------
-//
-// Constructor for iterations over global tables such as registered namespaces or aliases.
-
-XMPIterator::XMPIterator ( XMP_StringPtr  /*schemaNS*/,
-                             XMP_StringPtr  /*propName*/,
-						   XMP_OptionBits options ) : clientRefs(0), info(IterInfo(options,0))
-{
-
-	XMP_Throw ( "Unimplemented XMPIterator constructor for global tables", kXMPErr_Unimplemented );
-
-}	// XMPIterator for global tables
-
 // -------------------------------------------------------------------------------------------------
 // ~XMPIterator
 // -----------
@@ -552,7 +537,7 @@ XMPIterator::Next ( XMP_StringPtr *	 schemaNS,
 	}
 	
 	*schemaNS = info.currSchema.c_str();
-	*nsSize   = info.currSchema.size();
+	*nsSize   = static_cast<XMP_StringLen>(info.currSchema.size());
 
 	*propOptions = info.currPos->options;
 
@@ -564,7 +549,7 @@ XMPIterator::Next ( XMP_StringPtr *	 schemaNS,
 	if ( ! (*propOptions & kXMP_SchemaNode) ) {
 
 		*propPath = info.currPos->fullPath.c_str();
-		*pathSize = info.currPos->fullPath.size();
+		*pathSize = static_cast<XMP_StringLen>(info.currPos->fullPath.size());
 
 		if ( info.options & kXMP_IterJustLeafName ) {
 			*propPath += info.currPos->leafOffset;
@@ -574,7 +559,7 @@ XMPIterator::Next ( XMP_StringPtr *	 schemaNS,
 		
 		if ( ! (*propOptions & kXMP_PropCompositeMask) ) {
 			*propValue = xmpNode->value.c_str();
-			*valueSize = xmpNode->value.size();
+			*valueSize = static_cast<XMP_StringLen>(xmpNode->value.size());
 		}
 
 	}
