@@ -79,7 +79,7 @@ using namespace std;
 // ! also made sure that for a logical clip path the rootPath is an existing folder, and that the
 // ! file exists for a full file path.
 
-bool SonyHDV_CheckFormat ( XMP_FileFormat format,
+bool SonyHDV_CheckFormat ( XMP_FileFormat /*format*/,
 						   const std::string & rootPath,
 						   const std::string & gpName,
 						   const std::string & parentName,
@@ -604,10 +604,10 @@ static void RemoveTimeStampFromClipName(std::string &clipName)
 // SonyHDV_MetaHandler::MakeIndexFilePath
 // ======================================
 
-bool SonyHDV_MetaHandler::MakeIndexFilePath ( std::string& idxPath, const std::string& rootPath, const std::string& leafName )
+bool SonyHDV_MetaHandler::MakeIndexFilePath ( std::string& idxPath, const std::string& rootPath_, const std::string& leafName )
 {
 	std::string tempPath;
-	tempPath = rootPath;
+	tempPath = rootPath_;
 	tempPath += kDirChar;
 	tempPath += "VIDEO";
 	tempPath += kDirChar;
@@ -626,8 +626,8 @@ bool SonyHDV_MetaHandler::MakeIndexFilePath ( std::string& idxPath, const std::s
 	// Scanning code taken from SonyHDV_CheckFormat
 	// Can be isolated to a separate function.
 
-	std::string clipName = leafName;
-	RemoveTimeStampFromClipName(clipName);
+	std::string clipName_ = leafName;
+	RemoveTimeStampFromClipName(clipName_);
 
 	Host_IO::AutoFolder aFolder;
 	std::string childName;
@@ -639,10 +639,10 @@ bool SonyHDV_MetaHandler::MakeIndexFilePath ( std::string& idxPath, const std::s
 		if ( childLen < 4 ) continue;
 		MakeUpperCase ( &childName );
 		if ( childName.compare ( childLen-4, 4, ".IDX" ) != 0 ) continue;
-		if ( childName.compare ( 0, clipName.size(), clipName ) == 0 ) {
+		if ( childName.compare ( 0, clipName_.size(), clipName_ ) == 0 ) {
 			found = true;
-			clipName = childName;
-			clipName.erase ( childLen-4 );
+			clipName_ = childName;
+			clipName_.erase ( childLen-4 );
 		}
 	}
 	aFolder.Close();
@@ -650,7 +650,7 @@ bool SonyHDV_MetaHandler::MakeIndexFilePath ( std::string& idxPath, const std::s
 
 	idxPath = tempPath;
 	idxPath += kDirChar;
-	idxPath += clipName;
+	idxPath += clipName_;
 	idxPath += ".IDX";
 
 	return true;
@@ -859,7 +859,7 @@ void SonyHDV_MetaHandler::CacheFileData()
 	this->xmpPacket.erase();
 	this->xmpPacket.append ( (size_t)xmpLen, ' ' );
 
-	XMP_Int32 ioCount = xmpFile->ReadAll ( (void*)this->xmpPacket.data(), (XMP_Int32)xmpLen );
+	/*XMP_Int32 ioCount =*/ xmpFile->ReadAll ( (void*)this->xmpPacket.data(), (XMP_Int32)xmpLen );
 
 	this->packetInfo.offset = 0;
 	this->packetInfo.length = (XMP_Int32)xmpLen;
@@ -941,7 +941,7 @@ void SonyHDV_MetaHandler::UpdateFile ( bool doSafeUpdate )
 // SonyHDV_MetaHandler::WriteTempFile
 // ==================================
 
-void SonyHDV_MetaHandler::WriteTempFile ( XMP_IO* tempRef )
+void SonyHDV_MetaHandler::WriteTempFile ( XMP_IO* /*tempRef*/ )
 {
 
 	// ! WriteTempFile is not supposed to be called for handlers that own the file.
