@@ -114,7 +114,7 @@ TIFF_MetaHandler::~TIFF_MetaHandler()
 void TIFF_MetaHandler::CacheFileData()
 {
 	XMP_IO*      fileRef    = this->parent->ioRef;
-	XMP_PacketInfo & packetInfo = this->packetInfo;
+	/*XMP_PacketInfo & packetInfo = this->packetInfo;*/
 
 	XMP_AbortProc abortProc  = this->parent->abortProc;
 	void *        abortArg   = this->parent->abortArg;
@@ -273,8 +273,7 @@ void TIFF_MetaHandler::ProcessXMP()
 	// Process the legacy metadata.
 
 	if ( haveIPTC && (! haveXMP) && (iptcDigestState == kDigestMatches) ) iptcDigestState = kDigestMissing;
-	bool parseIPTC = (iptcDigestState != kDigestMatches) || (! readOnly);
-	if ( parseIPTC ) iptc.ParseMemoryDataSets ( iptcInfo.dataPtr, iptcInfo.dataLen );
+	if (iptcInfo.dataLen) iptc.ParseMemoryDataSets ( iptcInfo.dataPtr, iptcInfo.dataLen );
 	ImportPhotoData ( tiff, iptc, psir, iptcDigestState, &this->xmpObj, options );
 
 	this->containsXMP = true;	// Assume we now have something in the XMP.
@@ -293,11 +292,12 @@ void TIFF_MetaHandler::ProcessXMP()
 
 void TIFF_MetaHandler::UpdateFile ( bool doSafeUpdate )
 {
+	IgnoreParam(doSafeUpdate);
 	XMP_Assert ( ! doSafeUpdate );	// This should only be called for "unsafe" updates.
 
 	XMP_IO*   destRef    = this->parent->ioRef;
-	XMP_AbortProc abortProc  = this->parent->abortProc;
-	void *        abortArg   = this->parent->abortArg;
+	/*XMP_AbortProc abortProc  = this->parent->abortProc;*/
+	/*void *        abortArg   = this->parent->abortArg;*/
 
 	XMP_Int64 oldPacketOffset = this->packetInfo.offset;
 	XMP_Int32 oldPacketLength = this->packetInfo.length;
