@@ -85,7 +85,7 @@ using namespace std;
 
 // ! Using explicit '/' as a separator when creating paths, it works on Windows.
 
-bool XDCAMEX_CheckFormat ( XMP_FileFormat format,
+bool XDCAMEX_CheckFormat ( XMP_FileFormat /*format*/,
 						   const std::string & _rootPath,
 						   const std::string & gpName,
 						   const std::string & parentName,
@@ -305,29 +305,29 @@ void XDCAMEX_MetaHandler::MakeLegacyDigest ( std::string * digestStr )
 	if ( this->clipMetadata == 0 ) return;	// Bail if we don't have any legacy XML.
 	XMP_Assert ( this->expat != 0 );
 
-	XMP_StringPtr xdcNS = this->xdcNS.c_str();
+	XMP_StringPtr xdcNS_ = this->xdcNS.c_str();
 	XML_NodePtr legacyContext, legacyProp;
 
-	legacyContext = this->clipMetadata->GetNamedElement ( xdcNS, "Access" );
+	legacyContext = this->clipMetadata->GetNamedElement ( xdcNS_, "Access" );
 	if ( legacyContext == 0 ) return;
 
 	MD5_CTX    context;
 	unsigned char digestBin [16];
 	MD5Init ( &context );
 
-	legacyProp = legacyContext->GetNamedElement ( xdcNS, "Creator" );
+	legacyProp = legacyContext->GetNamedElement ( xdcNS_, "Creator" );
 	if ( (legacyProp != 0) && legacyProp->IsLeafContentNode() && (! legacyProp->content.empty()) ) {
 		const XML_Node * xmlValue = legacyProp->content[0];
 		MD5Update ( &context, (XMP_Uns8*)xmlValue->value.c_str(), (unsigned int)xmlValue->value.size() );
 	}
 
-	legacyProp = legacyContext->GetNamedElement ( xdcNS, "CreationDate" );
+	legacyProp = legacyContext->GetNamedElement ( xdcNS_, "CreationDate" );
 	if ( (legacyProp != 0) && legacyProp->IsLeafContentNode() && (! legacyProp->content.empty()) ) {
 		const XML_Node * xmlValue = legacyProp->content[0];
 		MD5Update ( &context, (XMP_Uns8*)xmlValue->value.c_str(), (unsigned int)xmlValue->value.size() );
 	}
 
-	legacyProp = legacyContext->GetNamedElement ( xdcNS, "LastUpdateDate" );
+	legacyProp = legacyContext->GetNamedElement ( xdcNS_, "LastUpdateDate" );
 	if ( (legacyProp != 0) && legacyProp->IsLeafContentNode() && (! legacyProp->content.empty()) ) {
 		const XML_Node * xmlValue = legacyProp->content[0];
 		MD5Update ( &context, (XMP_Uns8*)xmlValue->value.c_str(), (unsigned int)xmlValue->value.size() );
@@ -592,7 +592,7 @@ void XDCAMEX_MetaHandler::CacheFileData()
 	this->xmpPacket.erase();
 	this->xmpPacket.append ( (size_t)xmpLen, ' ' );
 
-	XMP_Int32 ioCount = xmpFile->ReadAll ( (void*)this->xmpPacket.data(), (XMP_Int32)xmpLen );
+	/*XMP_Int32 ioCount =*/ xmpFile->ReadAll ( (void*)this->xmpPacket.data(), (XMP_Int32)xmpLen );
 
 	this->packetInfo.offset = 0;
 	this->packetInfo.length = (XMP_Int32)xmpLen;
@@ -624,12 +624,18 @@ void XDCAMEX_MetaHandler::GetTakeDuration ( const std::string & takeURI, std::st
 
 	std::string takeDir ( takeURI );
 	takeDir.erase ( 0, 1 );	// Change the leading "//" to "/", then all '/' to kDirChar.
+#if XMP_MacBuild
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wunreachable-code"
+#endif
 	if ( kDirChar != '/' ) {
 		for ( size_t i = 0, limit = takeDir.size(); i < limit; ++i ) {
 			if ( takeDir[i] == '/' ) takeDir[i] = kDirChar;
 		}
 	}
-
+#if XMP_MacBuild
+#pragma clang diagnostic pop
+#endif 
 	std::string takePath ( this->rootPath );
 	takePath += kDirChar;
 	takePath += "BPAV";
@@ -694,14 +700,14 @@ void XDCAMEX_MetaHandler::GetTakeDuration ( const std::string & takeURI, std::st
 // ========================================
 
 bool XDCAMEX_MetaHandler::GetMediaProMetadata ( SXMPMeta * xmpObjPtr,
-											  	const std::string& clipUMID,
+											  	const std::string& clipUMID_,
 											  	bool digestFound )
 {
 	// Build a directory string to the MEDIAPRO file.
 
 	std::string mediaproPath;
 	this->MakeMediaproPath ( &mediaproPath );
-	return XDCAM_Support::GetMediaProLegacyMetadata ( xmpObjPtr, clipUMID, mediaproPath, digestFound );
+	return XDCAM_Support::GetMediaProLegacyMetadata ( xmpObjPtr, clipUMID_, mediaproPath, digestFound );
 
 }	// XDCAMEX_MetaHandler::GetMediaProMetadata
 
@@ -709,7 +715,7 @@ bool XDCAMEX_MetaHandler::GetMediaProMetadata ( SXMPMeta * xmpObjPtr,
 // XDCAMEX_MetaHandler::GetTakeUMID
 // ================================
 
-void XDCAMEX_MetaHandler::GetTakeUMID ( const std::string& clipUMID,
+void XDCAMEX_MetaHandler::GetTakeUMID ( const std::string& clipUMID_,
 										std::string&	   takeUMID,
 										std::string&	   takeXMLURI )
 {
@@ -737,7 +743,7 @@ void XDCAMEX_MetaHandler::GetTakeUMID ( const std::string& clipUMID,
 	// Parse MEDIAPRO.XML.
 
 	XML_NodePtr mediaproRootElem = 0;
-	XML_NodePtr contentContext = 0, materialContext = 0;
+	XML_NodePtr contentContext = 0/*, materialContext = 0*/;
 
 	Host_IO::FileRef hostRef = Host_IO::Open ( mediapropath.c_str(), Host_IO::openReadOnly );
 	if ( hostRef == Host_IO::noFileRef ) return;	// The open failed.
@@ -798,7 +804,7 @@ void XDCAMEX_MetaHandler::GetTakeUMID ( const std::string& clipUMID,
 
 				XMP_StringPtr compUMID = componentElement->GetAttrValue ( "umid" );
 
-				if ( (compUMID != 0) && (compUMID == clipUMID) ) {
+				if ( (compUMID != 0) && (compUMID == clipUMID_) ) {
 					takeUMID = umid;
 					takeXMLURI = uri;
 					break;
@@ -880,7 +886,7 @@ void XDCAMEX_MetaHandler::ProcessXMP()
 
 	// Check the legacy digest.
 
-	XMP_StringPtr legacyNS = this->legacyNS.c_str();
+	XMP_StringPtr legacyNS_ = this->legacyNS.c_str();
 	this->clipMetadata = rootElem;	// ! Save the NonRealTimeMeta pointer for other use.
 
 	std::string oldDigest, newDigest;
@@ -893,7 +899,7 @@ void XDCAMEX_MetaHandler::ProcessXMP()
 	// If we get here we need find and import the actual legacy elements using the current namespace.
 	// Either there is no old digest in the XMP, or the digests differ. In the former case keep any
 	// existing XMP, in the latter case take new legacy values.
-	this->containsXMP = XDCAM_Support::GetLegacyMetadata ( &this->xmpObj, rootElem, legacyNS, digestFound, thisUMID );
+	this->containsXMP = XDCAM_Support::GetLegacyMetadata ( &this->xmpObj, rootElem, legacyNS_, digestFound, thisUMID );
 
 	// If this clip is part of a take, add the take number to the relation field, and get the
 	// duration from the take metadata.
@@ -1029,7 +1035,7 @@ void XDCAMEX_MetaHandler::UpdateFile ( bool doSafeUpdate )
 // XDCAMEX_MetaHandler::WriteTempFile
 // ==================================
 
-void XDCAMEX_MetaHandler::WriteTempFile ( XMP_IO* tempRef )
+void XDCAMEX_MetaHandler::WriteTempFile ( XMP_IO* /*tempRef*/ )
 {
 
 	// ! WriteTempFile is not supposed to be called for handlers that own the file.
