@@ -48,7 +48,7 @@ ChunkController::ChunkController( IChunkBehavior* chunkBehavior, XMP_Bool bigEnd
 	mChunkBehavior->setMovablePaths( &mChunkPaths );
 }
 
-ChunkController::~ChunkController()
+ChunkController::~ChunkController() noexcept(false)
 {
 	XMP_Validate( mRoot != NULL, "ERROR inserting Chunk. mRoot is NULL.", kXMPErr_InternalFailure );
 	XMP_Assert(dynamic_cast<Chunk*>(mRoot) == static_cast<Chunk*>(mRoot));
@@ -623,7 +623,7 @@ std::string ChunkController::dumpTree( )
 
 	if ( mTrailingGarbageSize != 0 )
 	{
-		snprintf( buffer, 255, "\n Trailing Bytes: %llu",	mTrailingGarbageSize );
+		snprintf( buffer, 255, "\n Trailing Bytes: %llu", (long long unsigned)mTrailingGarbageSize );
 
 		std::string str(buffer);
 		ret.append(str);
