@@ -489,11 +489,11 @@ XMP_Uns32 PSIR_FileWriter::UpdateMemoryResources ( void** dataPtr )
 // ====================================
 
 XMP_Uns32 PSIR_FileWriter::UpdateFileResources ( XMP_IO* sourceRef, XMP_IO* destRef,
-												 XMP_AbortProc abortProc, void * abortArg,
+                                                 XMP_AbortProc /*abortProc*/, void * /*abortArg*/,
 												 XMP_ProgressTracker* progressTracker )
 {
 	const XMP_Uns32 zero32 = 0;
-	const bool checkAbort = (abortProc != 0);
+	/*const bool checkAbort = (abortProc != 0);*/
 
 	struct RsrcHeader {
 		XMP_Uns32 type;
