@@ -91,10 +91,11 @@ enum {	// Constants for the type field of a tag, as defined by TIFF.
 	kTIFF_SRationalType   = 10,
 	kTIFF_FloatType       = 11,
 	kTIFF_DoubleType      = 12,
-	kTIFF_LastType        = 12
+	kTIFF_IFDType		  = 13,
+	kTIFF_LastType		  = kTIFF_IFDType
 };
 
-static const size_t kTIFF_TypeSizes[]    = { 0, 1, 1, 2, 4, 8, 1, 1, 2, 4, 8, 4, 8 };
+static const size_t kTIFF_TypeSizes[]    = { 0, 1, 1, 2, 4, 8, 1, 1, 2, 4, 8, 4, 8, 4 };
 
 static const bool kTIFF_IsIntegerType[]  = { 1, 1, 0, 1, 1, 0, 1, 0, 1, 1, 0, 0, 0 };
 static const bool kTIFF_IsRationalType[] = { 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0 };
@@ -639,8 +640,9 @@ public:
 	// The condenseStream parameter to UpdateMemoryStream can be used to rewrite the full stream
 	// instead of appending. This will discard any MakerNote tags and risks breaking offsets that
 	// are hidden. This can be necessary though to try to make the TIFF fit in a JPEG file.
-
-	virtual void ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData = true ) = 0;
+	
+	// isAlredyLittle is provided for case when data contain no information about Endianess, So need not to check for header
+	virtual void ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData = true, bool isAlreadyLittle = false ) = 0;
 	virtual void ParseFileStream   ( XMP_IO* fileRef ) = 0;
 
 	virtual void IntegrateFromPShop6 ( const void * buriedPtr, size_t buriedLen ) = 0;
@@ -706,9 +708,9 @@ public:
 
 	bool GetTag ( XMP_Uns8 ifd, XMP_Uns16 id, TagInfo* info ) const;
 
-	void SetTag ( XMP_Uns8 ifd, XMP_Uns16 id, XMP_Uns16 type, XMP_Uns32 count, const void* dataPtr ) { NotAppropriate(); };
+	void SetTag ( XMP_Uns8 /*ifd*/, XMP_Uns16 /*id*/, XMP_Uns16 /*type*/, XMP_Uns32 /*count*/, const void* /*dataPtr*/ ) { NotAppropriate(); };
 
-	void DeleteTag ( XMP_Uns8 ifd, XMP_Uns16 id ) { NotAppropriate(); };
+	void DeleteTag ( XMP_Uns8 /*ifd*/, XMP_Uns16 /*id*/ ) { NotAppropriate(); };
 
 	XMP_Uns32 GetValueOffset ( XMP_Uns8 ifd, XMP_Uns16 id ) const;
 
@@ -731,18 +733,19 @@ public:
 
 	bool GetTag_EncodedString ( XMP_Uns8 ifd, XMP_Uns16 id, std::string* utf8Str ) const;
 
-	void SetTag_EncodedString ( XMP_Uns8 ifd, XMP_Uns16 id, const std::string& utf8Str, XMP_Uns8 encoding ) { NotAppropriate(); };
+	void SetTag_EncodedString ( XMP_Uns8 /*ifd*/, XMP_Uns16 /*id*/, const std::string& /*utf8Str*/, XMP_Uns8 /*encoding*/ ) { NotAppropriate(); };
 
 	bool IsChanged() { return false; };
 	bool IsLegacyChanged() { return false; };
 
-	void ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData = true );
-	void ParseFileStream   ( XMP_IO* fileRef ) { NotAppropriate(); };
+	// isAlredyLittle is provided for case when data contain no information about Endianess, So need not to check for header
+	void ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData = true, bool isAlreadyLittle = false );
+	void ParseFileStream   ( XMP_IO* /*fileRef*/ ) { NotAppropriate(); };
 
-	void IntegrateFromPShop6 ( const void * buriedPtr, size_t buriedLen ) { NotAppropriate(); };
+	void IntegrateFromPShop6 ( const void * /*buriedPtr*/, size_t /*buriedLen*/ ) { NotAppropriate(); };
 
-	XMP_Uns32 UpdateMemoryStream ( void** dataPtr, bool condenseStream = false ) { if ( dataPtr != 0 ) *dataPtr = tiffStream; return tiffLength; };
-	void      UpdateFileStream   ( XMP_IO* fileRef, XMP_ProgressTracker* progressTracker ) { NotAppropriate(); };
+	XMP_Uns32 UpdateMemoryStream ( void** dataPtr, bool condenseStream = false ) { IgnoreParam(condenseStream); if ( dataPtr != 0 ) *dataPtr = tiffStream; return tiffLength; };
+	void      UpdateFileStream   ( XMP_IO* /*fileRef*/, XMP_ProgressTracker* /*progressTracker*/ ) { NotAppropriate(); };
 
 	TIFF_MemoryReader() : ownedStream(false), tiffStream(0), tiffLength(0) {};
 
@@ -778,7 +781,8 @@ private:
 
 	static void SortIFD ( TweakedIFDInfo* thisIFD );
 
-	XMP_Uns32 ProcessOneIFD ( XMP_Uns32 ifdOffset, XMP_Uns8 ifd );
+	// ModifiedInitialCheck is provided for case when data contain no header
+	XMP_Uns32 ProcessOneIFD ( XMP_Uns32 ifdOffset, XMP_Uns8 ifd, bool ModifiedInitialCheck = false );
 
 	const TweakedIFDEntry* FindTagInIFD ( XMP_Uns8 ifd, XMP_Uns16 id ) const;
 
@@ -852,7 +856,8 @@ public:
 
 	enum { kDoNotCopyData = false };
 
-	void ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData = true );
+	// isAlredyLittle is provided for case when data contain no information about Endianess, So need not to check for header
+	void ParseMemoryStream ( const void* data, XMP_Uns32 length, bool copyData = true, bool isAlreadyLittle = false );
 	void ParseFileStream   ( XMP_IO* fileRef );
 
 	void IntegrateFromPShop6 ( const void * buriedPtr, size_t buriedLen );
