@@ -22,6 +22,7 @@
 	#include "XMPFiles/source/FileHandlers/JPEG_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/PSD_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/TIFF_Handler.hpp"
+	#include "XMPFiles/source/FileHandlers/GIF_Handler.hpp"
 #endif
 
 #if EnableDynamicMediaHandlers
@@ -36,8 +37,9 @@
 	#include "XMPFiles/source/FileHandlers/RIFF_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/SonyHDV_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/SWF_Handler.hpp"
-	#include "XMPFiles/source/FileHandlers/XDCAM_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/XDCAMEX_Handler.hpp"
+	#include "XMPFiles/source/FileHandlers/XDCAMFAM_Handler.hpp"
+	#include "XMPFiles/source/FileHandlers/XDCAMSAM_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/WEBP_Handler.hpp"
 #endif
 
@@ -46,7 +48,7 @@
 	#include "XMPFiles/source/FileHandlers/PNG_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/PostScript_Handler.hpp"
 	#include "XMPFiles/source/FileHandlers/UCF_Handler.hpp"
-	#include "XMPFiles/source/FileHandlers/GIF_Handler.hpp"
+	#include "XMPFiles/source/FileHandlers/SVG_Handler.hpp"
 #endif
 
 //#if EnablePacketScanning
@@ -123,8 +125,8 @@ void HandlerRegistry::initialize()
 #if EnableDynamicMediaHandlers
 	allOK &= this->registerFolderHandler ( kXMP_P2File, kP2_HandlerFlags, P2_CheckFormat, P2_MetaHandlerCTor );
 	allOK &= this->registerFolderHandler ( kXMP_SonyHDVFile, kSonyHDV_HandlerFlags, SonyHDV_CheckFormat, SonyHDV_MetaHandlerCTor );
-	allOK &= this->registerFolderHandler ( kXMP_XDCAM_FAMFile, kXDCAM_HandlerFlags, XDCAM_CheckFormat, XDCAM_MetaHandlerCTor );
-	allOK &= this->registerFolderHandler ( kXMP_XDCAM_SAMFile, kXDCAM_HandlerFlags, XDCAM_CheckFormat, XDCAM_MetaHandlerCTor );
+	allOK &= this->registerFolderHandler ( kXMP_XDCAM_FAMFile, kXDCAMFAM_HandlerFlags, XDCAMFAM_CheckFormat, XDCAMFAM_MetaHandlerCTor );
+	allOK &= this->registerFolderHandler ( kXMP_XDCAM_SAMFile, kXDCAMSAM_HandlerFlags, XDCAMSAM_CheckFormat, XDCAMSAM_MetaHandlerCTor );
 	allOK &= this->registerFolderHandler ( kXMP_XDCAM_EXFile, kXDCAMEX_HandlerFlags, XDCAMEX_CheckFormat, XDCAMEX_MetaHandlerCTor );
 #endif
 
@@ -135,6 +137,7 @@ void HandlerRegistry::initialize()
 	allOK &= this->registerNormalHandler ( kXMP_JPEGFile, kJPEG_HandlerFlags, JPEG_CheckFormat, JPEG_MetaHandlerCTor );
 	allOK &= this->registerNormalHandler ( kXMP_PhotoshopFile, kPSD_HandlerFlags, PSD_CheckFormat, PSD_MetaHandlerCTor );
 	allOK &= this->registerNormalHandler ( kXMP_TIFFFile, kTIFF_HandlerFlags, TIFF_CheckFormat, TIFF_MetaHandlerCTor );
+	allOK &= this->registerNormalHandler( kXMP_GIFFile, kGIF_HandlerFlags, GIF_CheckFormat, GIF_MetaHandlerCTor );
 #endif
 
 #if EnableDynamicMediaHandlers
@@ -154,10 +157,10 @@ void HandlerRegistry::initialize()
 	allOK &= this->registerNormalHandler ( kXMP_InDesignFile, kInDesign_HandlerFlags, InDesign_CheckFormat, InDesign_MetaHandlerCTor );
 	allOK &= this->registerNormalHandler ( kXMP_PNGFile, kPNG_HandlerFlags, PNG_CheckFormat, PNG_MetaHandlerCTor );
 	allOK &= this->registerNormalHandler ( kXMP_UCFFile, kUCF_HandlerFlags, UCF_CheckFormat, UCF_MetaHandlerCTor );
-	allOK &= this->registerNormalHandler ( kXMP_GIFFile, kGIF_HandlerFlags, GIF_CheckFormat, GIF_MetaHandlerCTor );
 	// ! EPS and PostScript have the same handler, EPS is a proper subset of PostScript.
 	allOK &= this->registerNormalHandler ( kXMP_EPSFile, kPostScript_HandlerFlags, PostScript_CheckFormat, PostScript_MetaHandlerCTor );
 	allOK &= this->registerNormalHandler ( kXMP_PostScriptFile, kPostScript_HandlerFlags, PostScript_CheckFormat, PostScript_MetaHandlerCTor );
+	allOK &= this->registerNormalHandler ( kXMP_SVGFile, kSVG_HandlerFlags, SVG_CheckFormat, SVG_MetaHandlerCTor );
 #endif
 
 	// ------------------------------------------------------------------------------------
@@ -930,7 +933,7 @@ XMPFileHandlerInfo* HandlerRegistry::tryFolderHandlers( XMP_FileFormat format,
 																   const std::string& parentName, 
 																   const std::string& leafName )
 {
-	IgnoreParam ( parentName );
+	IgnoreParam(leafName);
 
 	// This is called when the input path to XMPFiles::OpenFile names an existing file. We need to
 	// quickly decide if this might be inside a folder-handler's structure. See if the containing
