@@ -36,6 +36,14 @@
 	#include "XMPFiles/source/FileHandlers/Generic_Handler.hpp"
 #endif
 
+#include "XMPCore/XMPCoreDefines.h"
+#if ENABLE_CPP_DOM_MODEL
+	#include "XMPCore/Interfaces/IMetadata.h"
+	#include "XMPCore/Interfaces/INodeIterator.h"
+	#include "XMPCommon/Interfaces/IUTF8String.h"
+	#include "XMPCore/Interfaces/ICoreObjectFactory.h"
+#endif
+
 // =================================================================================================
 /// \file XMPFiles.cpp
 /// \brief High level support to access metadata in files of interest to Adobe applications.
@@ -81,12 +89,12 @@ const char * kXMPFiles_EmbeddedVersion   = kXMPFiles_VersionMessage;
 const char * kXMPFiles_EmbeddedCopyright = kXMPFilesName " " kXMP_CopyrightStr;
 
 #define EMPTY_FILE_PATH ""
-#define XMP_FILES_STATIC_START try { int a;
-#define XMP_FILES_STATIC_END1(severity) a = 1; } catch ( XMP_Error & error ) { sDefaultErrorCallback.NotifyClient ( (severity), error, EMPTY_FILE_PATH ); }
-#define XMP_FILES_STATIC_END2(filePath, severity) a = 1; } catch ( XMP_Error & error ) { sDefaultErrorCallback.NotifyClient ( (severity), error, (filePath) ); }
-#define XMP_FILES_START try { int b;
-#define XMP_FILES_END1(severity) b = 1; } catch ( XMP_Error & error ) { errorCallback.NotifyClient ( (severity), error, this->filePath.c_str() ); }
-#define XMP_FILES_END2(filePath, severity) b = 1; } catch ( XMP_Error & error ) { errorCallback.NotifyClient ( (severity), error, (filePath) ); }
+#define XMP_FILES_STATIC_START try { /*int a;*/
+#define XMP_FILES_STATIC_END1(severity) /*a = 1;*/ } catch ( XMP_Error & error ) { sDefaultErrorCallback.NotifyClient ( (severity), error, EMPTY_FILE_PATH ); }
+#define XMP_FILES_STATIC_END2(filePath, severity) /*a = 1;*/ } catch ( XMP_Error & error ) { sDefaultErrorCallback.NotifyClient ( (severity), error, (filePath) ); }
+#define XMP_FILES_START try { /*int b;*/
+#define XMP_FILES_END1(severity) /*b = 1;*/ } catch ( XMP_Error & error ) { errorCallback.NotifyClient ( (severity), error, this->filePath.c_str() ); }
+#define XMP_FILES_END2(filePath, severity) /*b = 1;*/ } catch ( XMP_Error & error ) { errorCallback.NotifyClient ( (severity), error, (filePath) ); }
 #define XMP_FILES_STATIC_NOTIFY_ERROR(errorCallbackPtr, filePath, severity, error)							\
 	if ( (errorCallbackPtr) != NULL ) (errorCallbackPtr)->NotifyClient ( (severity), (error), (filePath) );
 
@@ -574,6 +582,7 @@ XMPFiles::GetFileModDate ( XMP_StringPtr    clientPath,
 
 	dummyParent.format = handlerInfo->format;
 	if ( format ) *format = handlerInfo->format;
+	dummyParent.openFlags = handlerInfo->flags;
 
 	dummyParent.handler = handlerInfo->handlerCTor ( &dummyParent );
 
@@ -616,6 +625,64 @@ XMPFiles::GetFileModDate ( XMP_StringPtr    clientPath,
 
 // =================================================================================================
 
+/* class static */
+bool
+XMPFiles::GetFileModDate ( const Common::XMPFileHandlerInfo& hdlInfo,
+						   XMP_StringPtr    clientPath,
+						   XMP_DateTime *   modDate,
+						   XMP_OptionBits   /* options = 0 */ )
+{
+	XMP_FILES_STATIC_START
+	Host_IO::FileMode clientMode;
+	std::string fileExt;	// Used to check for excluded files.
+	bool excluded = FileIsExcluded ( clientPath, &fileExt, &clientMode, &sDefaultErrorCallback );	// ! Fills in fileExt and clientMode.
+	if ( excluded ) return false;
+
+	XMPFiles dummyParent;	// GetFileModDate is static, but the handler needs a parent.
+	dummyParent.SetFilePath ( clientPath );
+	dummyParent.format = hdlInfo.format;
+	dummyParent.openFlags = hdlInfo.flags;
+	dummyParent.handler = hdlInfo.handlerCTor ( &dummyParent );
+
+	bool ok = false;
+
+	std::vector <std::string> resourceList;
+	try{
+		XMP_DateTime lastModDate;
+		XMP_DateTime junkDate;
+		if ( modDate == 0 ) modDate = &junkDate;
+		dummyParent.handler->FillAssociatedResources ( &resourceList );
+		size_t countRes = resourceList.size();
+		for ( size_t index = 0; index < countRes ; ++index ){
+			XMP_StringPtr curFilePath = resourceList[index].c_str();
+			if( Host_IO::GetFileMode ( curFilePath ) != Host_IO::kFMode_IsFile ) continue;// only interested in files
+			if (!Host_IO::GetModifyDate ( curFilePath, &lastModDate ) ) continue;
+			if ( ! ok || ( SXMPUtils::CompareDateTime ( *modDate , lastModDate ) < 0 ) ) 
+			{
+				*modDate = lastModDate;
+				ok = true;
+			}
+		}
+	}
+	catch(...){
+		// Fallback to the old way 
+		// eventually this method would go away as 
+		// soon as the implementation for
+		// GetAssociatedResources is added to all 
+		// the file/Plugin Handlers
+		ok = dummyParent.handler->GetFileModDate ( modDate );
+	}
+	delete dummyParent.handler;
+	dummyParent.handler = 0;
+
+	return ok;
+	XMP_FILES_STATIC_END2 ( clientPath, kXMPErrSev_OperationFatal )
+	return false;
+
+}	// XMPFiles::GetFileModDate
+
+// =================================================================================================
+
 /* class static */
 bool
 XMPFiles::GetAssociatedResources ( 
@@ -661,6 +728,7 @@ XMPFiles::GetAssociatedResources (
 	// Fill in the format output. Call the handler to get the Associated Resources.
 
 	dummyParent.format = handlerInfo->format;
+	dummyParent.openFlags = handlerInfo->flags;
 
 	dummyParent.handler = handlerInfo->handlerCTor ( &dummyParent );
 	
@@ -686,6 +754,53 @@ XMPFiles::GetAssociatedResources (
 
 }	// XMPFiles::GetAssociatedResources
 
+// =================================================================================================
+
+/* class static */
+bool
+XMPFiles::GetAssociatedResources (
+		const Common::XMPFileHandlerInfo& hdlInfo,
+		XMP_StringPtr              filePath,
+        std::vector<std::string> * resourceList,
+        XMP_OptionBits             /* options = 0 */ )
+{
+	XMP_FILES_STATIC_START
+	Host_IO::FileMode clientMode;
+	std::string fileExt;	// Used to check for excluded files.
+	bool excluded = FileIsExcluded ( filePath, &fileExt, &clientMode, &sDefaultErrorCallback );	// ! Fills in fileExt and clientMode.
+	if ( excluded ) return false;
+
+	XMPFiles dummyParent;	// GetFileModDate is static, but the handler needs a parent.
+	dummyParent.SetFilePath ( filePath );
+	dummyParent.format = hdlInfo.format;
+	dummyParent.openFlags = hdlInfo.flags;
+	dummyParent.handler = hdlInfo.handlerCTor ( &dummyParent );
+
+	try {
+		dummyParent.handler->FillAssociatedResources ( resourceList );
+	} catch ( XMP_Error& error ) {
+		if ( error.GetID() == kXMPErr_Unimplemented ) {
+			XMP_FILES_STATIC_NOTIFY_ERROR ( &sDefaultErrorCallback, filePath, kXMPErrSev_Recoverable, error );
+			return false;
+		} else {
+			throw;
+		}
+	}
+	XMP_Assert ( ! resourceList->empty() );
+
+	delete dummyParent.handler;
+	dummyParent.handler = 0;
+	
+	return true;
+
+	XMP_FILES_STATIC_END2 ( filePath, kXMPErrSev_OperationFatal )
+	return false;
+
+}	// XMPFiles::GetAssociatedResources
+
+// =================================================================================================
+
+/* class static */
 bool 
 XMPFiles::IsMetadataWritable (
 		XMP_StringPtr  filePath,
@@ -732,6 +847,7 @@ XMPFiles::IsMetadataWritable (
 
 
 	dummyParent.format = handlerInfo->format;
+	dummyParent.openFlags = handlerInfo->flags;
 	dummyParent.handler = handlerInfo->handlerCTor ( &dummyParent );
 	
 	// We don't require any of the files to be opened at this point.
@@ -759,6 +875,58 @@ XMPFiles::IsMetadataWritable (
 	return true;
 } // XMPFiles::IsMetadataWritable 
 
+// =================================================================================================
+
+/* class static */
+bool 
+XMPFiles::IsMetadataWritable (
+		const Common::XMPFileHandlerInfo& hdlInfo,
+		XMP_StringPtr  filePath,
+        XMP_Bool *     writable,
+        XMP_OptionBits /* options = 0 */ )
+{
+	XMP_FILES_STATIC_START
+	Host_IO::FileMode clientMode;
+	std::string fileExt;	// Used to check for excluded files.
+	bool excluded = FileIsExcluded ( filePath, &fileExt, &clientMode, &sDefaultErrorCallback );	// ! Fills in fileExt and clientMode.
+	if ( excluded ) return false;
+
+	if ( writable == 0 ) {
+		XMP_Throw("Boolean parameter is required for IsMetadataWritable() API.", kXMPErr_BadParam);
+	} else {
+		*writable = kXMP_Bool_False;
+	}
+
+	XMPFiles dummyParent;	// GetFileModDate is static, but the handler needs a parent.
+	dummyParent.SetFilePath ( filePath );
+	dummyParent.format = hdlInfo.format;
+	dummyParent.openFlags = hdlInfo.flags;
+	dummyParent.handler = hdlInfo.handlerCTor ( &dummyParent );
+
+	// We don't require any of the files to be opened at this point.
+	// Also, if We don't close them then this will be a problem for embedded handlers because we will be checking
+	// write permission on the same file which could be open (in some mode) already.
+	CloseLocalFile(&dummyParent);
+	
+	try {
+		*writable = ConvertBoolToXMP_Bool( dummyParent.handler->IsMetadataWritable() );
+	} catch ( XMP_Error& error ) {
+		delete dummyParent.handler;
+		dummyParent.handler = 0;
+		if ( error.GetID() == kXMPErr_Unimplemented ) {
+			XMP_FILES_STATIC_NOTIFY_ERROR ( &sDefaultErrorCallback, filePath, kXMPErrSev_Recoverable, error );
+			return false;
+		} else {
+			throw;
+		}
+	}
+	if ( dummyParent.handler ) {
+		delete dummyParent.handler;
+		dummyParent.handler = 0;
+	}
+	XMP_FILES_STATIC_END2 ( filePath, kXMPErrSev_OperationFatal )
+	return true;
+}  // XMPFiles::IsMetadataWritable 
 
 // =================================================================================================
 
@@ -1004,11 +1172,11 @@ static bool DoOpenFile( XMPFiles* thiz,
 
 bool
 XMPFiles::OpenFile ( XMP_StringPtr  clientPath,
-	                 XMP_FileFormat format /* = kXMP_UnknownFile */,
-	                 XMP_OptionBits openFlags /* = 0 */ )
+	                 XMP_FileFormat format1 /* = kXMP_UnknownFile */,
+	                 XMP_OptionBits openFlags1 /* = 0 */ )
 {
 	XMP_FILES_START
-	return DoOpenFile ( this, 0, clientPath, format, openFlags );
+	return DoOpenFile ( this, 0, clientPath, format1, openFlags1 );
 	XMP_FILES_END2 ( clientPath, kXMPErrSev_FileFatal )
 	return false;
 }
@@ -1019,12 +1187,12 @@ XMPFiles::OpenFile ( XMP_StringPtr  clientPath,
 
 bool
 XMPFiles::OpenFile ( XMP_IO*        clientIO,
-	                 XMP_FileFormat format /* = kXMP_UnknownFile */,
-	                 XMP_OptionBits openFlags /* = 0 */ )
+	                 XMP_FileFormat format1 /* = kXMP_UnknownFile */,
+	                 XMP_OptionBits openFlags1 /* = 0 */ )
 {
 	XMP_FILES_START
 	this->progressTracker = 0;	// Progress tracking is not supported for client-managed I/O.
-	return DoOpenFile ( this, clientIO, "", format, openFlags );
+	return DoOpenFile ( this, clientIO, "", format1, openFlags1 );
 	XMP_FILES_END1 ( kXMPErrSev_FileFatal )
 	return false;
 
@@ -1032,11 +1200,11 @@ XMPFiles::OpenFile ( XMP_IO*        clientIO,
 
 bool XMPFiles::OpenFile ( const Common::XMPFileHandlerInfo&	hdlInfo,
 						 XMP_IO*							clientIO,
-						 XMP_OptionBits						openFlags /*= 0*/ )
+						 XMP_OptionBits						openFlags1 /*= 0*/ )
 {
 	XMP_FILES_START
 	this->progressTracker = 0;	// Progress tracking is not supported for client-managed I/O.
-	return DoOpenFile ( this, hdlInfo, clientIO, NULL, openFlags );
+	return DoOpenFile ( this, hdlInfo, clientIO, NULL, openFlags1 );
 	XMP_FILES_END1 ( kXMPErrSev_FileFatal )
 	return false;
 
@@ -1047,12 +1215,12 @@ bool XMPFiles::OpenFile ( const Common::XMPFileHandlerInfo&	hdlInfo,
 // =================================================================================================
 
 bool XMPFiles::OpenFile ( const Common::XMPFileHandlerInfo&	hdlInfo,
-						 XMP_StringPtr						filePath,
-						 XMP_OptionBits						openFlags /*= 0*/ )
+						 XMP_StringPtr						filePath1,
+						 XMP_OptionBits						openFlags1 /*= 0*/ )
 {
 	XMP_FILES_START
-	return DoOpenFile ( this, hdlInfo, NULL, filePath, openFlags );
-	XMP_FILES_END2 (filePath, kXMPErrSev_FileFatal )
+	return DoOpenFile ( this, hdlInfo, NULL, filePath1, openFlags1 );
+	XMP_FILES_END2 (filePath1, kXMPErrSev_FileFatal )
 	return false;
 }
 
@@ -1086,7 +1254,7 @@ XMPFiles::CloseFile ( XMP_OptionBits closeFlags /* = 0 */ )
 		XMP_Throw ( "XMPFiles::CloseFile - Safe update not supported", kXMPErr_Unavailable );
 	}
 
-	if ( (this->progressTracker != 0) && this->UsesLocalIO() ) {
+	if ( (this->progressTracker != 0) && this->UsesLocalIO() && this->ioRef != NULL ) {
 		XMPFiles_IO * localFile = (XMPFiles_IO*)this->ioRef;
 		localFile->SetProgressTracker ( this->progressTracker );
 	}
@@ -1219,26 +1387,26 @@ XMPFiles::CloseFile ( XMP_OptionBits closeFlags /* = 0 */ )
 // =================================================================================================
 
 bool
-XMPFiles::GetFileInfo ( XMP_StringPtr *  filePath /* = 0 */,
+XMPFiles::GetFileInfo ( XMP_StringPtr *  filePath1 /* = 0 */,
                         XMP_StringLen *  pathLen /* = 0 */,
-	                    XMP_OptionBits * openFlags /* = 0 */,
-	                    XMP_FileFormat * format /* = 0 */,
+	                    XMP_OptionBits * openFlags1 /* = 0 */,
+	                    XMP_FileFormat * format1 /* = 0 */,
 	                    XMP_OptionBits * handlerFlags /* = 0 */ ) const
 {
 	XMP_FILES_START
 	if ( this->handler == 0 ) return false;
-	XMPFileHandler * handler = this->handler;
+	/*XMPFileHandler * handler = this->handler;*/
 
-	if ( filePath == 0 ) filePath = &voidStringPtr;
+	if ( filePath1 == 0 ) filePath1 = &voidStringPtr;
 	if ( pathLen == 0 ) pathLen = &voidStringLen;
-	if ( openFlags == 0 ) openFlags = &voidOptionBits;
-	if ( format == 0 ) format = &voidFileFormat;
+	if ( openFlags1 == 0 ) openFlags1 = &voidOptionBits;
+	if ( format1 == 0 ) format1 = &voidFileFormat;
 	if ( handlerFlags == 0 ) handlerFlags = &voidOptionBits;
 
-	*filePath     = this->filePath.c_str();
+	*filePath1    = this->filePath.c_str();
 	*pathLen      = (XMP_StringLen) this->filePath.size();
-	*openFlags    = this->openFlags;
-	*format       = this->format;
+	*openFlags1   = this->openFlags;
+	*format1      = this->format;
 	*handlerFlags = this->handler->handlerFlags;
 	XMP_FILES_END1 ( kXMPErrSev_FileFatal )
 	return true;
@@ -1248,14 +1416,14 @@ XMPFiles::GetFileInfo ( XMP_StringPtr *  filePath /* = 0 */,
 // =================================================================================================
 
 void
-XMPFiles::SetAbortProc ( XMP_AbortProc abortProc,
-						 void *        abortArg )
+XMPFiles::SetAbortProc ( XMP_AbortProc abortProc1,
+						 void *        abortArg1 )
 {
 	XMP_FILES_START
-	this->abortProc = abortProc;
-	this->abortArg  = abortArg;
+	this->abortProc = abortProc1;
+	this->abortArg  = abortArg1;
 
-	XMP_Assert ( (abortProc != (XMP_AbortProc)0) || (abortArg != (void*)(unsigned long long)0xDEADBEEFULL) );	// Hack to test the assert callback.
+	XMP_Assert ( (abortProc1 != (XMP_AbortProc)0) || (abortArg1 != (void*)(unsigned long long)0xDEADBEEFULL) );	// Hack to test the assert callback.
 	XMP_FILES_END1 ( kXMPErrSev_OperationFatal )
 }	// XMPFiles::SetAbortProc
 
@@ -1306,7 +1474,7 @@ XMPFiles::GetXMP ( SXMPMeta *       xmpObj /* = 0 */,
 			if ( xmpObj != 0 ) {
 				// ! Don't use Clone, that replaces the internal ref in the local xmpObj, leaving the client unchanged!
 				xmpObj->Erase();
-				SXMPUtils::ApplyTemplate ( xmpObj, this->handler->xmpObj, applyTemplateFlags );
+					SXMPUtils::ApplyTemplate(xmpObj, this->handler->xmpObj, applyTemplateFlags);
 			}
 			if ( xmpPacket != 0 ) *xmpPacket = this->handler->xmpPacket.c_str();
 			if ( xmpPacketLen != 0 ) *xmpPacketLen = (XMP_StringLen) this->handler->xmpPacket.size();
@@ -1322,9 +1490,8 @@ XMPFiles::GetXMP ( SXMPMeta *       xmpObj /* = 0 */,
 		if ( xmpObj != 0 ) *xmpObj = this->handler->xmpObj.Clone();
 	#else
 		if ( xmpObj != 0 ) {
-			// ! Don't use Clone, that replaces the internal ref in the local xmpObj, leaving the client unchanged!
 			xmpObj->Erase();
-			SXMPUtils::ApplyTemplate ( xmpObj, this->handler->xmpObj, applyTemplateFlags );
+			SXMPUtils::ApplyTemplate(xmpObj, this->handler->xmpObj, applyTemplateFlags);
 		}
 	#endif
 
@@ -1482,6 +1649,7 @@ XMPFiles::CanPutXMP ( XMP_StringPtr xmpPacket,
 
 }	// XMPFiles::CanPutXMP
 
+
 // =================================================================================================
 
 /* class-static */
@@ -1513,6 +1681,11 @@ XMPFiles::SetProgressCallback ( const XMP_ProgressTracker::CallbackInfo & cbInfo
 	
 	if ( cbInfo.clientProc != 0 ) {
 		this->progressTracker = new XMP_ProgressTracker ( cbInfo );
+		if ( this->handler != 0 ) {		 // Provided to support ProgressTracker in Plugins
+			XMP_ProgressTracker::CallbackInfo * callbackInfo = new XMP_ProgressTracker::CallbackInfo(cbInfo);
+			this->handler->SetProgressCallback( callbackInfo ) ;
+			delete callbackInfo;
+		}
 	}
 	XMP_FILES_END1 ( kXMPErrSev_OperationFatal )
 
@@ -1559,6 +1732,8 @@ void XMPFiles::SetErrorCallback ( XMPFiles_ErrorCallbackWrapper	wrapperProc,
 	this->errorCallback.clientProc = clientProc;
 	this->errorCallback.context = context;
 	this->errorCallback.limit = limit;
+	if ( this->handler != 0 )	 // Provided to support ErrroCallback in Plugins
+		this->handler->SetErrorCallback( ErrorCallbackBox( errorCallback.wrapperProc, errorCallback.clientProc, errorCallback.context, errorCallback.limit ) );
 	XMP_FILES_END1 ( kXMPErrSev_OperationFatal )
 }	// SetErrorCallback
 
@@ -1571,6 +1746,8 @@ void XMPFiles::ResetErrorCallbackLimit ( XMP_Uns32 limit ) {
 	this->errorCallback.limit = limit;
 	this->errorCallback.notifications = 0;
 	this->errorCallback.topSeverity = kXMPErrSev_Recoverable;
+	if ( this->handler != 0 )		// Provided to support ErrroCallback in Plugins
+		this->handler->SetErrorCallback( ErrorCallbackBox( errorCallback.wrapperProc, errorCallback.clientProc, errorCallback.context, errorCallback.limit ) );
 	XMP_FILES_END1 ( kXMPErrSev_OperationFatal )
 }	// ResetErrorCallbackLimit
 
@@ -1594,13 +1771,13 @@ bool
 // This is const just to be usable from const XMPMeta functions.
 
 bool
-	XMPFiles::ErrorCallbackInfo::ClientCallbackWrapper ( XMP_StringPtr filePath,
+	XMPFiles::ErrorCallbackInfo::ClientCallbackWrapper ( XMP_StringPtr filePath1,
 														 XMP_ErrorSeverity severity,
 														 XMP_Int32 cause,
 														 XMP_StringPtr messsage ) const
 {
 	
-	XMP_StringPtr filePathPtr = filePath;
+	XMP_StringPtr filePathPtr = filePath1;
 	if ( filePathPtr == 0 ) {
 		filePathPtr = this->filePath.c_str();
 	}
