@@ -27,6 +27,8 @@
 #include "public/include/XMP.hpp"
 #include "public/include/XMP.incl_cpp"
 
+//#define ENABLE_XMP_CPP_INTERFACE 1;
+
 using namespace std;
 
 #if WIN_ENV
@@ -338,6 +340,7 @@ static void WriteMinorLabel ( FILE * log, const char * title )
 
 // -------------------------------------------------------------------------------------------------
 
+#if 0
 static XMP_Status DumpToString ( void * refCon, XMP_StringPtr outStr, XMP_StringLen outLen )
 {
 	XMP_Status	status	= 0;
@@ -351,6 +354,7 @@ static XMP_Status DumpToString ( void * refCon, XMP_StringPtr outStr, XMP_String
 	return status;
 	
 }	// DumpToString
+#endif
 
 // -------------------------------------------------------------------------------------------------
 
