@@ -118,6 +118,25 @@ void TagTree::setKeyValue(const std::string key,const std::string value, const s
 		Log::info( "    setKeyValue( %s |-> %s) [%s]", key.c_str(), value.c_str(), _comment.c_str() );
 }
 
+void TagTree::updateKeyValue ( const std::string key, const std::string value, const std::string _comment )
+{
+	Node* pCurNode = *nodeStack.rbegin ( ); //current Node
+	pCurNode->children.push_back ( Node ( key, value, _comment ) );
+
+	if ( key.size ( ) == 0 ) {		 // standalone comment?
+		if ( value.size ( ) != 0 ) // must have no value
+			Log::error ( "no key but value found." );
+		return;				// ==> do not add to tag-map
+	}
+
+	//add to Map -----------------------------------
+	lastNode = &*(pCurNode->children.rbegin ( ));
+	tagMap[key] = lastNode;
+
+	if ( verbose )
+		Log::info ( "    setKeyValue( %s |-> %s) [%s]", key.c_str ( ), value.c_str ( ), _comment.c_str ( ) );
+}
+
 void TagTree::digest(LFA_FileRef file,const std::string key /*=NULL*/,
 					   void* returnValue /*=""*/,
 					   XMP_Int32 numOfBytes /*=0*/ )
@@ -178,7 +197,7 @@ XMP_Int64 TagTree::digest64s(LFA_FileRef file,const std::string key /* ="" */ ,
 
 	if (!key.empty()) {
 		char out[25]; //longest is "18446744073709551615", 21 chars ==> 25
-		snprintf(out,24,"%lld",r); //signed, mind the trailing \0 on Mac btw
+		snprintf(out,24,"%lld", (long long)r); //signed, mind the trailing \0 on Mac btw
 		setKeyValue(key,out);
 	}
 	return r;
@@ -200,7 +219,7 @@ XMP_Uns64 TagTree::digest64u(LFA_FileRef file,const std::string key /* ="" */, b
 				snprintf(out , 24 , "%I64u" , r);
 			#else 
 				// MAC, UNIX
-				snprintf(out , 24 , "%llu" , r);
+				snprintf(out , 24 , "%llu" , (long long)r);
 			#endif
 		}
 		else
@@ -209,7 +228,7 @@ XMP_Uns64 TagTree::digest64u(LFA_FileRef file,const std::string key /* ="" */, b
 			#if WIN_ENV
 				snprintf( out , 24 , "0x%.16I64X" , r );
 			#else
-				snprintf( out , 24 , "0x%.16llX" , r );
+				snprintf( out , 24 , "0x%.16llX" , (long long)r );
 			#endif
 		}
 		setKeyValue(key,out);
