@@ -337,7 +337,7 @@ XMP_Int64 Host_IO::Seek ( Host_IO::FileRef refNum, XMP_Int64 offset, SeekMode mo
 			break;
 	}
 
-	XMP_Int64 newPos = (XMP_Int64) lseek ( refNum, offset, mode );
+	XMP_Int64 newPos = (XMP_Int64) lseek ( refNum, offset, posMode );
 	if ( newPos == -1 ) XMP_Throw ( "Host_IO::Seek, lseek failure", kXMPErr_ExternalFailure );
 
 	return newPos;
@@ -357,7 +357,7 @@ XMP_Uns32 Host_IO::Read ( Host_IO::FileRef refNum, void * buffer, XMP_Uns32 coun
 	ssize_t bytesRead = read ( refNum, buffer, count );
 	if ( bytesRead == -1 ) XMP_Throw ( "Host_IO::Read, read failure", kXMPErr_ReadError );
 
-	return bytesRead;
+	return static_cast<XMP_Uns32>( bytesRead );
 
 }	// Host_IO::Read
 
